Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
ghost/__init__.py | 5 | 0 | 0 | 100%
ghost/abs_resources.py | 179 | 30 | 0 | 83%
ghost/client.py | 152 | 24 | 0 | 84%
ghost/exceptions.py | 16 | 1 | 0 | 94%
ghost/resources.py | 62 | 15 | 0 | 76%
ghost/results.py | 75 | 6 | 0 | 92%
setup.py | 10 | 10 | 0 | 0%
test_ghost.py | 245 | 32 | 0 | 87%
Total | 744 | 118 | 0 | 84%

No items found using the specified filter.